Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(323)

Unified Diff: chrome/browser/autocomplete/search_provider.h

Issue 291005: Allow the history URL provider to handle input of type QUERY. This helps in ... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: Created 11 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/autocomplete/search_provider.h
===================================================================
--- chrome/browser/autocomplete/search_provider.h (revision 29226)
+++ chrome/browser/autocomplete/search_provider.h (working copy)
@@ -236,15 +236,16 @@
// if the search is from the keyword provider.
int CalculateRelevanceForHistory(const base::Time& time,
bool is_keyword) const;
- // |suggestion_value| is the index of the suggestion in |suggest_results| that
- // was returned from the server; the best suggestion is suggestion number 0.
- // |is_keyword| is true if the search is from the keyword provider.
- int CalculateRelevanceForSuggestion(const SuggestResults& suggest_results,
- size_t suggestion_number,
+ // |result_number| is the index of the suggestion in the result set from the
+ // server; the best suggestion is suggestion number 0. |is_keyword| is true
+ // if the search is from the keyword provider.
+ int CalculateRelevanceForSuggestion(size_t num_results,
+ size_t result_number,
bool is_keyword) const;
// |suggestion_value| is same as above. |is_keyword| is true if the navigation
// result was suggested by the keyword provider.
- int CalculateRelevanceForNavigation(size_t suggestion_value,
+ int CalculateRelevanceForNavigation(size_t num_results,
+ size_t result_number,
bool is_keyword) const;
// Creates an AutocompleteMatch for "Search <engine> for |query_string|" with
@@ -236,15 +236,16 @@
bool is_keyword) const;
- // |suggestion_value| is same as above. |is_keyword| is true if the navigation
+ // |result_number| is same as above. |is_keyword| is true if the navigation
// result was suggested by the keyword provider.

Powered by Google App Engine
This is Rietveld 408576698